@@ -30,7 +30,8 @@ class Decoder(srd.Decoder):
     desc = 'EM4100 100-150kHz RFID protocol.'
     license = 'gplv2+'
     inputs = ['logic']
-    outputs = ['em4100']
+    outputs = []
+    tags = ['IC', 'RFID']
     channels = (
         {'id': 'data', 'name': 'Data', 'desc': 'Data line'},
     )
@@ -62,6 +63,9 @@ class Decoder(srd.Decoder):
     )
 
     def __init__(self):
+        self.reset()
+
+    def reset(self):
         self.samplerate = None
         self.oldpin = None
         self.last_samplenum = None
@@ -212,7 +216,7 @@ class Decoder(srd.Decoder):
             raise SamplerateError('Cannot decode without samplerate.')
 
         # Initialize internal state from the very first sample.
-        (pin,) = self.wait({'skip': 1})
+        (pin,) = self.wait()
         self.oldpin = pin
         self.last_samplenum = self.samplenum
         self.lastlast_samplenum = self.samplenum
